(window.webpackJsonp=window.webpackJsonp||[]).push([[73],{202:function(e,t,a){e.exports=function(){"use strict";return[{locale:"ia",pluralRuleFunction:function(e,t){var a=!String(e).split(".")[1];return t?"other":1==e&&a?"one":"other"},fields:{year:{displayName:"anno",relative:{0:"iste anno",1:"le anno proxime","-1":"le anno passate"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},"year-short":{displayName:"an.",relative:{0:"iste anno",1:"le anno proxime","-1":"le anno passate"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},month:{displayName:"mense",relative:{0:"iste mense",1:"le mense proxime","-1":"le mense passate"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-short":{displayName:"mns.",relative:{0:"iste mense",1:"le mense proxime","-1":"le mense passate"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},day:{displayName:"die",relative:{0:"hodie",1:"deman","-1":"heri"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-short":{displayName:"die",relative:{0:"hodie",1:"deman","-1":"heri"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},hour:{displayName:"hora",relative:{0:"iste hora"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-short":{displayName:"hr.",relative:{0:"iste hora"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},minute:{displayName:"minuta",relative:{0:"iste minuta"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-short":{displayName:"min.",relative:{0:"iste minuta"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},second:{displayName:"secunda",relative:{0:"ora"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-short":{displayName:"sec.",relative:{0:"ora"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}}}}]}()}}]);
//# sourceMappingURL=73.9bfb29d2ef2e592924a4.index.js.map