(window.webpackJsonp=window.webpackJsonp||[]).push([[88],{217:function(e,t,i){e.exports=function(){"use strict";return[{locale:"jv",pluralRuleFunction:function(e,t){return"other"},fields:{year:{displayName:"taun",relative:{0:"taun iki",1:"taun ngarep","-1":"taun wingi"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},"year-short":{displayName:"taun",relative:{0:"taun iki",1:"taun ngarep","-1":"taun wingi"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},month:{displayName:"sasi",relative:{0:"sasi iki",1:"sasi ngarep","-1":"sasi wingi"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-short":{displayName:"sasi",relative:{0:"sasi iki",1:"sasi ngarep","-1":"sasi wingi"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},day:{displayName:"dino",relative:{0:"saiki",1:"sesuk","-1":"wingi"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-short":{displayName:"dino",relative:{0:"saiki",1:"sesuk","-1":"wingi"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},hour:{displayName:"jam",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-short":{displayName:"jam",relative:{0:"this hour"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},minute:{displayName:"menit",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-short":{displayName:"menit",relative:{0:"this minute"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},second:{displayName:"detik",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-short":{displayName:"detik",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}}}}]}()}}]);
//# sourceMappingURL=88.9bfb29d2ef2e592924a4.index.js.map